| Actor | Created by marvin on 01.05.15 in project shoebill-api. |
| ActorEvent | Base class for all ActorEvents, such as ActorStreamInEvent |
| ActorStreamInEvent | This event represents the OnActorStreamIn callback from Pawn. |
| ActorStreamOutEvent | This event represents the OnActorStreamOut event from Pawn. |
| AlreadyExistException | |
| AmxCallable | |
| AmxCallEvent | Created by marvin on 24.01.15 in project shoebill-api. |
| AmxHook | Created by marvin on 03.03.15 in project shoebill-api. |
| AmxInstance | |
| AmxInstanceEvent | This event is used for all AmxEvents and contains a AmxInstance variable. |
| AmxInstanceManager | |
| AmxInstanceManager.Instance | |
| AmxLoadEvent | This event is called when an AmxInstance has been loaded. |
| AmxUnloadEvent | This event is called when an AmxInstance is unloaded. |
| AngledLocation | |
| Animation | Created by marvin on 15.02.15 in project shoebill-api. |
| Area | |
| Area3D |
| BulletHitType |
| CameraCutStyle | To be used with setCameraLookAt, interpolateCameraPos and interpolateCameraLookAt. |
| Checkpoint | |
| CheckpointEnterEvent | This event represents the OnPlayerEnterCheckpoint callback from Pawn. |
| CheckpointEvent | This abstract event is the base class for every Checkpoint event |
| CheckpointLeaveEvent | This event represents the OnPlayerLeaveCheckpoint of Pawn. |
| ClickPlayerSource | |
| Color | |
| ConnectionStatus | Created by marvin on 14.05.15 in project shoebill-api. |
| CreationFailedException |
| Destroyable | |
| DestroyEvent | This event will be called whenever an internal object is destroyed, such as SampObject or Vehicle. |
| DialogCloseEvent | |
| DialogCloseEvent.DialogCloseType | |
| DialogEvent | This class is the base class of every DialogEvent. |
| DialogId | |
| DialogResponseEvent | |
| DialogShowEvent | |
| DialogStyle | To be used with showDialog. |
| DisconnectReason |
| FightStyle | To be used with setFightStyle and getFightStyle. |
| Gamemode | |
| GameModeExitEvent | Created by MarvinWindows on 14.12.2014. |
| GameModeInitEvent | Created by MarvinWindows on 14.12.2014. |
| GameTextStyle |
| IllegalLengthException | |
| IncomingConnectionEvent | |
| Interior | Created by Spikes on 17.02.2015 in project shoebill-api Copyright (c) 2015 Julian Suhl. |
| Label | |
| Location | |
| LocationZone | Created by marvin on 16.02.15 in project shoebill-api. |
| MapIconStyle | To be used with setMapIcon. |
| Menu | |
| MenuEvent | |
| MenuExitedEvent | |
| MenuSelectedEvent |
| NoGamemodeAssignedException |
| ObjectEditResponse | Used in PlayerEditObjectEvent and PlayerEditAttachedObjectEvent. |
| ObjectEvent | |
| ObjectMaterialSize | To be used with setMaterialText. |
| ObjectMaterialTextAlign | To be used with setMaterialText. |
| ObjectMovedEvent |
| Quaternion |
| RaceCheckpoint | |
| RaceCheckpointEnterEvent | |
| RaceCheckpointEvent | This abstract class is the base class for every RaceCheckpointEvent. |
| RaceCheckpointLeaveEvent | |
| RaceCheckpointType | Type of checkpoint. |
| Radius | |
| RangeCheckable3D | |
| RconCommandEvent | |
| RconLoginEvent | |
| RecordType | To be used with startRecord. |
| Reference<T> | Created by marvin on 28.01.16. |
| ReferenceFloat | Created by marvin on 05.03.15 in project shoebill-api. |
| ReferenceInt | Created by marvin on 05.03.15 in project shoebill-api. |
| ReferenceString | Created by marvin on 05.03.15 in project shoebill-api. |
| Resource | |
| ResourceDescription | |
| ResourceDisableEvent | |
| ResourceEnableEvent | |
| ResourceEvent | |
| ResourceLoadEvent | |
| ResourceManager | |
| ResourceType | |
| ResourceUnloadEvent | |
| ReturnType | Created by marvin on 15.01.16. |
| SampObject | |
| SampObjectFactory | |
| SampObjectManager | |
| SampObjectStore | SA-MP object interface, managing all SA-MP objects that exist. |
| Server | |
| Service | |
| ServiceEntry | |
| ServiceEvent | |
| ServiceManager | |
| ServiceRegisterEvent | |
| ServiceStore | |
| ServiceUnregisterEvent | |
| Shoebill | Shoebill main interface, provides the basic manager instance and functions. |
| Shoebill.Instance | |
| ShoebillVersion | Shoebill version information interface. |
| ShopName | To be used with setShopName. |
| SkinModel | |
| SkinModel.Gender | |
| SpawnInfo | |
| SpecialAction | To be used with setSpecialAction or getSpecialAction. |
| SpectateMode | To be used with spectate. |
| Textdraw | |
| TextDrawAlign | To be used with TextDraw and PlayerTextDraw. |
| TextdrawBase | |
| TextDrawFont | To be used with TextDraw and PlayerTextDraw. |
| Time | |
| Timer | |
| Timer.TimerCallback | |
| TrailerUpdateEvent | Created by marvin on 18.09.14. |
| UnoccupiedVehicleUpdateEvent |
| Vector2D | |
| Vector3D | |
| Vehicle | |
| VehicleColor | Created by marvin on 17.02.15 in project shoebill-api. |
| VehicleComponent | |
| VehicleComponentModel | |
| VehicleComponentSlot | To be used with VehicleComponent. |
| VehicleCreateEvent | Created by marvin on 01.11.14. |
| VehicleDamage | |
| VehicleDeathEvent | |
| VehicleEnterEvent | |
| VehicleEvent | |
| VehicleExitEvent | |
| VehicleModel | |
| VehicleModel.VehicleType | |
| VehicleModelInfoType | To be used with getModelInfo. |
| VehicleModEvent | |
| VehiclePaintjobEvent | |
| VehicleParam | |
| VehicleRelated | |
| VehicleResprayEvent | |
| VehicleSirenStateChangeEvent | Created by marvin on 01.05.15 in project shoebill-api. |
| VehicleSpawnEvent | |
| VehicleState | Created by marvin on 02.05.15 in project shoebill-api. |
| VehicleStreamInEvent | |
| VehicleStreamOutEvent | |
| VehicleUpdateDamageEvent | |
| VehicleUpdateEvent | |
| Velocity |
| WeaponData | |
| WeaponModel | To be used with a range of weapon methods. |
| WeaponSkill | To be used with PlayerWeaponSkill. |
| WeaponSlot | Created by BigETI |
| WeaponState | To be used with getWeaponState. |
| Weather | Created by Spikes on 29.2.204. |
| World |
| Zone |